@@ -140,17 +140,12 @@ class Storage(driver.Base):
         logger.info("get_size path:%s" % path)
         try:
             path1 = self._init_path(path)
-            tmp_file = tempfile.mktemp(suffix=path1, prefix='docker_registry_image_local', dir="/tmp")
-            object_instance = self._jss.bucket(self._bucket).object(path1)
-            object_instance.download(local_file_path=tmp_file)
+            keyInfo = self._jss.bucket(self._bucket).get_key(path1)
             
-            return os.path.getsize(tmp_file)
+            return keyInfo.content_length
         except Exception as e:
             logger.error("get_size error:%s" % e)
             raise exceptions.FileNotFoundError("File not found %s" % path)
-        finally:
-            if os.path.exists(tmp_file):
-                os.remove(tmp_file)
         
     def exists(self, path):
         logger.info("exists path:%s" % path)
